package App::Jawk;
use strict;

BEGIN {
our $VERSION = '0.10';
};

1;

# this is just here for the documentation

=head1 NAME

jawk -- like awk, but post-modern and perly. AKA, Josh's Awk.

=head1 SYNOPSIS

See documentation for <bin/jawk>

=head1 DESCRIPTION

See documentation for <bin/jawk>

=head1 COPYRIGHT

Copyright (c) 2010-2012 Josh Rabinowitz, All Rights Reserved.

=head1 AUTHORS

Josh Rabinowitz

=cut    


